@@ -49,7 +49,7 @@ class APaymentData(BaseModel):
     reason: str
     amount: float
     expire_at: str
-    split: Union[Dict[str, Optional[float]], List[Optional[APaymentDataSplit]], None]
+    split: Union[List[Optional[APaymentDataSplit]], Dict[str, Optional[float]], None]
     notify: ANotify
     landing: Landing
 
