@@ -16,8 +16,10 @@ class ApplicationTestCase(TestCase):
         application = Application(**get_application_data())
         payment_data_v2 = APaymentData(**get_application_payment_data(split=get_split_data_v2()))
         application_v2 = Application(**get_application_data(payment_data=payment_data_v2))
+        payment_data_empty_split = APaymentData(**get_application_payment_data(split=[]))
         self.assertEqual(application.id, UUID('3c819c1d-6587-448d-8ba4-3b6f23e87ed4'))
         self.assertEqual(application_v2.payment_data.split, {'c_1': 14.0, 'c_2': None})
+        self.assertEqual(payment_data_empty_split.split, [])
         with self.assertRaises(ValidationError):
             APaymentData(
                 **get_application_payment_data(
